package com.muyu.cloud.pay.service.impl;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.pay.domain.OrderPayCustomer;
import com.muyu.cloud.pay.domain.OrderPayInfo;
import com.muyu.cloud.pay.domain.req.CustomerListReq;
import com.muyu.cloud.pay.domain.resp.CustomerOrderPaySimpleResp;
import com.muyu.cloud.pay.domain.resp.CustomerResp;
import com.muyu.cloud.pay.mapper.OrderPayCustomerMapper;
import com.muyu.cloud.pay.service.OrderPayCustomerService;
import com.muyu.cloud.pay.service.OrderPayService;
import com.muyu.common.core.enums.SysPayType;
import com.muyu.common.nacos.remote.NacosServiceRemote;
import com.muyu.common.nacos.service.NacosServiceService;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @Author：liuxinyue
 * @Package：com.muyu.cloud.pay.service.impl
 * @Project：cloud-pay
 * @name：OrderPayCustomerServiceImpl
 * @Date：2024/7/31 20:01
 */
@Log4j2
@Service
public class OrderPayCustomerServiceImpl
        extends ServiceImpl<OrderPayCustomerMapper, OrderPayCustomer>
        implements OrderPayCustomerService{

    @Resource(type = OrderPayServiceImpl.class)
    private OrderPayService orderPayService;


    @Resource
    private NacosServiceService nacosServiceService;


    /**
     * 查询客户集合
     * @param customerListReq 请求参数
     * @return 客户集合
     */
    @Override
    public List<CustomerResp> selectList(CustomerListReq customerListReq) {

        LambdaQueryWrapper<OrderPayCustomer> queryWrapper = new LambdaQueryWrapper<>();

        queryWrapper.like(
                StringUtils.isNotEmpty(customerListReq.getAppName()),
                OrderPayCustomer::getAppName,customerListReq.getAppName()
        );

        queryWrapper.like(
                StringUtils.isNotEmpty(customerListReq.getAppCode()),
                OrderPayCustomer::getAppCode,customerListReq.getAppCode()
        );

        queryWrapper.eq(
                StringUtils.isNotEmpty(customerListReq.getStatus()),
                OrderPayCustomer::getStatus,customerListReq.getStatus()
        );

        List<OrderPayCustomer> orderPayCustomerList = this.list(queryWrapper);
        return  orderPayCustomerList.stream()
                .map(orderPayCustomer -> CustomerResp.customerBuild(orderPayCustomer,
                        () ->   orderPayService.selectOrderPayByAppCodeAndLimit(orderPayCustomer.getAppCode(),5)
                            .stream()
                            .map(OrderPayInfo::buildCustomerOrderPaySimpleResp)
                            .toList()))
                .toList();

    }

    @Override
    public List<String> getCustomerAllList() {

        List<String> nacosServerAllList = nacosServiceService.nacosServerAllList();

        LambdaQueryWrapper<OrderPayCustomer> queryWrapper = new LambdaQueryWrapper<>();

        queryWrapper.select(OrderPayCustomer::getAppCode);

        List<OrderPayCustomer> orderPayCustomerList=this.list(queryWrapper);

        Set<String> customerSet
                =orderPayCustomerList.stream().map(OrderPayCustomer::getAppCode).collect(Collectors.toSet());
        return nacosServerAllList.stream()
                .filter(nacosServer -> !customerSet.contains(nacosServer))
                .toList();
    }
}



//List<CustomerOrderPaySimpleResp> customerOrderPaySimpleRespList=new ArrayList<>();
//            for (OrderPayInfo orderPayInfo : orderPayInfoList) {
//
//CustomerOrderPaySimpleResp customerOrderPaySimpleResp = new CustomerOrderPaySimpleResp();
//                customerOrderPaySimpleResp.setCusOrderNumber(orderPayInfo.getCusOrderNumber());
//        customerOrderPaySimpleResp.setPrice(orderPayInfo.getPrice());
//        customerOrderPaySimpleResp.setChannelTypeName(SysPayType.getInfoByCode(orderPayInfo.getChannelType()));
//        customerOrderPaySimpleRespList.add(customerOrderPaySimpleResp);
//
//
//                customerResp.setOrderPaySimpleRespList(
//        orderPayCustomerList.stream()
//                                .map(OrderPayInfo::buildCustomerOrderPaySimpleResp)
//                                .toList()
//                );
//
//                        }

